pitchtools.split_chromatic_pitch_class_name
===========================================

.. autofunction:: abjad.tools.pitchtools.split_chromatic_pitch_class_name.split_chromatic_pitch_class_name
   :noindex:
